Index: lib/http_client.c
===================================================================
--- lib/http_client.c	(revision 6f10697380c620065731a5beece95c0f5bd652a0)
+++ lib/http_client.c	(revision 6b13103dad92d505e038c268af66aeb04b7b4d87)
@@ -345,10 +345,10 @@
 		/* Might be a \r\n from the last chunk. */
 		s = chunk;
-		while( isspace( *s ) )
+		while( g_ascii_isspace( *s ) )
 			s ++;
 		/* Chunk length. Might be incomplete. */
 		if( s < eos && sscanf( s, "%x", &clen ) != 1 )
 			return CR_ERROR;
-		while( isxdigit( *s ) )
+		while( g_ascii_isxdigit( *s ) )
 			s ++;
 		
Index: lib/ini.c
===================================================================
--- lib/ini.c	(revision 6f10697380c620065731a5beece95c0f5bd652a0)
+++ lib/ini.c	(revision 6b13103dad92d505e038c268af66aeb04b7b4d87)
@@ -63,9 +63,9 @@
 	char *e;
 
-	while( isspace( *in ) )
+	while( g_ascii_isspace( *in ) )
 		in++;
 
 	e = in + strlen( in ) - 1;
-	while( e > in && isspace( *e ) )
+	while( e > in && g_ascii_isspace( *e ) )
 		e--;
 	e[1] = 0;
Index: lib/json.c
===================================================================
--- lib/json.c	(revision 6f10697380c620065731a5beece95c0f5bd652a0)
+++ lib/json.c	(revision 6b13103dad92d505e038c268af66aeb04b7b4d87)
@@ -53,5 +53,5 @@
 static unsigned char hex_value (json_char c)
 {
-   if (isdigit(c))
+   if (g_ascii_isdigit(c))
       return c - '0';
 
@@ -609,5 +609,5 @@
                      default:
 
-                        if (isdigit (b) || b == '-')
+                        if (g_ascii_isdigit (b) || b == '-')
                         {
                            if (!new_value (&state, &top, &root, &alloc, json_integer))
@@ -616,5 +616,5 @@
                            if (!state.first_pass)
                            {
-                              while (isdigit (b) || b == '+' || b == '-'
+                              while (g_ascii_isdigit (b) || b == '+' || b == '-'
                                         || b == 'e' || b == 'E' || b == '.')
                               {
@@ -706,5 +706,5 @@
             case json_double:
 
-               if (isdigit (b))
+               if (g_ascii_isdigit (b))
                {
                   ++ num_digits;
Index: lib/ssl_gnutls.c
===================================================================
--- lib/ssl_gnutls.c	(revision 6f10697380c620065731a5beece95c0f5bd652a0)
+++ lib/ssl_gnutls.c	(revision 6b13103dad92d505e038c268af66aeb04b7b4d87)
@@ -318,5 +318,5 @@
 	gnutls_set_default_priority( conn->session );
 	gnutls_credentials_set( conn->session, GNUTLS_CRD_CERTIFICATE, xcred );
-	if( conn->hostname && !isdigit( conn->hostname[0] ) )
+	if( conn->hostname && !g_ascii_isdigit( conn->hostname[0] ) )
 		gnutls_server_name_set( conn->session, GNUTLS_NAME_DNS,
 		                        conn->hostname, strlen( conn->hostname ) );
Index: lib/ssl_openssl.c
===================================================================
--- lib/ssl_openssl.c	(revision 6f10697380c620065731a5beece95c0f5bd652a0)
+++ lib/ssl_openssl.c	(revision 6b13103dad92d505e038c268af66aeb04b7b4d87)
@@ -159,5 +159,5 @@
 	SSL_set_fd( conn->ssl, conn->fd );
 	
-	if( conn->hostname && !isdigit( conn->hostname[0] ) )
+	if( conn->hostname && !g_ascii_isdigit( conn->hostname[0] ) )
 		SSL_set_tlsext_host_name( conn->ssl, conn->hostname );
 	

Index: lib/misc.c
===================================================================
--- lib/misc.c	(revision 6f10697380c620065731a5beece95c0f5bd652a0)
+++ lib/misc.c	(revision 6b13103dad92d505e038c268af66aeb04b7b4d87)
@@ -163,5 +163,5 @@
 	while( *in )
 	{
-		if( *in == '<' && ( isalpha( *(in+1) ) || *(in+1) == '/' ) )
+		if( *in == '<' && ( g_ascii_isalpha( *(in+1) ) || *(in+1) == '/' ) )
 		{
 			/* If in points at a < and in+1 points at a letter or a slash, this is probably
@@ -198,5 +198,5 @@
 		{
 			cs = ++in;
-			while( *in && isalpha( *in ) )
+			while( *in && g_ascii_isalpha( *in ) )
 				in ++;
 			
@@ -314,5 +314,5 @@
 	for( i = j = 0; t[i]; i ++, j ++ )
 	{
 		/* Warning: isalnum() is locale-aware, so don't use it here! */
 		if( ( t[i] >= 'A' && t[i] <= 'Z' ) ||
 		    ( t[i] >= 'a' && t[i] <= 'z' ) ||
@@ -490,5 +490,5 @@
 	
 	while( *value )
-		if( !isdigit( *value ) )
+		if( !g_ascii_isdigit( *value ) )
 			return 0;
 		else
@@ -314,5 +314,5 @@
 	for( i = j = 0; t[i]; i ++, j ++ )
 	{
-		/* Warning: isalnum() is locale-aware, so don't use it here! */
+		/* Warning: g_ascii_isalnum() is locale-aware, so don't use it here! */
 		if( ( t[i] >= 'A' && t[i] <= 'Z' ) ||
 		    ( t[i] >= 'a' && t[i] <= 'z' ) ||